==> haskell-validity-bytestring-0.4.1.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-validity-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 validity-bytestring
version:              0.4.1.1
visibility:           public
id:                   validity-bytestring-0.4.1.1-1N4pXItilu4DYkKNN5fL0O
key:                  validity-bytestring-0.4.1.1-1N4pXItilu4DYkKNN5fL0O
license:              MIT
copyright:            Copyright: (c) 2016-2020 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Validity instances for bytestring
description:          Please see README.md
category:             Validity
abi:                  b1c354094c2c62775abe3a7cbc380fbe
exposed:              True
exposed-modules:      Data.Validity.ByteString
hidden-modules:       Paths_validity_bytestring
import-dirs:          /usr/lib/ghc-9.6.6/site-local/validity-bytestring-0.4.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/validity-bytestring-0.4.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/validity-bytestring-0.4.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-validity-bytestring
hs-libraries:         HSvalidity-bytestring-0.4.1.1-1N4pXItilu4DYkKNN5fL0O
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    validity-0.12.1.0-L5D7yphngJc1pFhWUuN10v

haddock-interfaces:
    /usr/share/doc/haskell-validity-bytestring/html/validity-bytestring.haddock

haddock-html:         /usr/share/doc/haskell-validity-bytestring/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-validity-bytestring-0.4.1.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-validity-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 validity-bytestring
version:              0.4.1.1
visibility:           public
id:                   validity-bytestring-0.4.1.1-CgskdPUQQ6O9LwLYBTTCkK
key:                  validity-bytestring-0.4.1.1-CgskdPUQQ6O9LwLYBTTCkK
license:              MIT
copyright:            Copyright: (c) 2016-2020 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Validity instances for bytestring
description:          Please see README.md
category:             Validity
abi:                  82f53ab6ca0902107b4e9bfa9d2083f0
exposed:              True
exposed-modules:      Data.Validity.ByteString
hidden-modules:       Paths_validity_bytestring
import-dirs:          /usr/lib/ghc-9.6.6/site-local/validity-bytestring-0.4.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/validity-bytestring-0.4.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/validity-bytestring-0.4.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-validity-bytestring
hs-libraries:         HSvalidity-bytestring-0.4.1.1-CgskdPUQQ6O9LwLYBTTCkK
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    validity-0.12.1.0-6hEdMU8bjrnLyURRA3tXkp

haddock-interfaces:
    /usr/share/doc/haskell-validity-bytestring/html/validity-bytestring.haddock

haddock-html:         /usr/share/doc/haskell-validity-bytestring/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
